import * as react_jsx_runtime from 'react/jsx-runtime';
import { SxProps } from '@mui/material';
import React from 'react';

interface ControlCommons {
    key?: string;
    displayName?: string;
    value?: string;
    mrnEntries?: {
        [key: string]: any;
    };
    hasChanged?: boolean;
    error?: {
        message: string;
    };
    required?: boolean;
    placeholder?: string;
    hasEdited?: "edited" | "not-edited" | undefined;
    "custom-attributes"?: CustomAttributes;
}
type FormVisibility = "hidden" | "visible" | "expert" | {
    hideOnCondition: string;
};
type GenAiPrompt = {
    displayValue: string;
    promptTemplate: string;
    profile?: string;
};
type GenAiPrompts = GenAiPrompt[];
interface CustomAttributes {
    media?: string;
    "mrn-ref"?: string;
    "mrn-ref-display-field"?: string;
    "mrn-ref-params"?: string;
    "mrn-ref-mrn-field"?: string;
    options?: InputFreeSoloOptions[];
    mrnPreview?: {
        displayField?: string;
        linkDisabled?: boolean;
    };
    submenu?: {
        icon?: string;
    };
    mrnSources?: MrnInputMultipleServices[];
    defaultValue?: string;
    defaultCollapseThreshold?: string;
    visibility?: {
        form?: FormVisibility;
        detailView?: "hidden" | "visible";
        table?: "hidden" | "visible";
    };
    editor?: "richtext" | "markdown" | "code" | "plate";
    viewer?: "html" | "markdown";
    tags?: string | string[];
    genAiPrompts?: GenAiPrompts;
    tooltip?: string;
    [key: string]: any;
}
type MrnInputMultipleServices = {
    name: string;
    mrn: string;
    query: string;
    mrnField: string;
    displayField: string;
    [key: string]: any;
};
interface GroupFormControl extends ControlCommons {
    control: "group";
    controls: FormControls;
}
interface InputFormControl extends ControlCommons {
    control: "input";
    type: "plain" | "html" | "hex" | "color" | "mrn" | "url" | "date" | "time" | "datetime" | "number" | "email" | "password" | "geolocation";
    placeholder?: string;
    pattern?: string;
    minLength?: number;
    maxLength?: number;
    step?: number;
}
interface InputFreeSoloOptions {
    value: string;
    text?: string;
    tooltip?: string;
    default?: "true" | "false" | undefined;
}
interface TextareaFormControl extends ControlCommons {
    control: "textarea";
    type: "plain" | "html" | "json";
}
interface CheckboxFormControl extends ControlCommons {
    control: "checkbox";
    selected?: boolean;
}
interface SelectFormControlOption extends Omit<ControlCommons, "displayName"> {
    value: string;
    text: string;
    phone?: string;
    selected?: boolean;
}
interface SelectFormControl extends ControlCommons {
    control: "select";
    options?: SelectFormControlOption[];
    multiple?: boolean;
}
interface MultiSelectFormControl extends Omit<SelectFormControl, "value"> {
    value?: string | string[];
}
interface ListFormControl extends ControlCommons {
    control: "list";
    items?: FormControls[];
    required?: boolean;
    template: FormControls;
}
type FormControl = InputFormControl | TextareaFormControl | CheckboxFormControl | SelectFormControl | MultiSelectFormControl | ListFormControl | GroupFormControl;
interface FormControls {
    [key: string]: FormControl;
}
type fileUploaderEndpoint = {
    url: string;
    name: string;
};
type FileUploaderConfig = {
    info?: string;
    endpoints?: fileUploaderEndpoint[];
    language?: string;
    previewUrl?: (url: string) => Promise<any>;
    authorizationHeader?: (url: string, method: string) => string;
};
interface FormBuilderConfigLink {
    href: string;
    rel: string;
    text: string;
}
interface FormBuilderConfig {
    method: "POST" | "GET";
    links: FormBuilderConfigLink[];
    error?: {
        message: string;
    };
    items: FormControls;
}
interface resolveUrl {
    (mrn: string, params: string, opts: any): Promise<any>;
}
type MessageType = string;
type MessageStatus = "error" | "success";
interface PostMessageProps {
    message: MessageType;
    profile: string;
}
type PostMessageResponse = {
    message: MessageType;
    model: string;
    usage: {
        answer: string;
        prompt: string;
        total: string;
    };
    status: MessageStatus;
};

type controlProps = {
    formProps?: {
        style?: React.CSSProperties;
    };
    inputProps?: {
        style?: React.CSSProperties;
    };
    mrnProps?: {
        disableMrnLink?: boolean;
    };
    selectProps?: {
        sx?: SxProps;
        textField?: {
            sx?: SxProps;
        };
        listBox?: {
            sx?: SxProps;
        };
    };
    footerProps?: {
        style?: React.CSSProperties;
        container?: {
            style?: React.CSSProperties;
        };
        submitButtonContainer?: {
            style?: React.CSSProperties;
        };
        submitButton?: {
            sx?: SxProps;
        };
    };
    addressProps?: {
        style?: React.CSSProperties;
        label?: {
            style?: React.CSSProperties;
        };
        container?: {
            style?: React.CSSProperties;
        };
    };
    controlWrapperProps?: {
        style?: React.CSSProperties;
        label?: {
            style?: React.CSSProperties;
        };
        container?: {
            style?: React.CSSProperties;
        };
    };
    groupProps?: {
        style?: React.CSSProperties;
        label?: {
            style?: React.CSSProperties;
        };
    };
    listProps?: {
        style?: React.CSSProperties;
        addButton?: {
            sx?: SxProps;
        };
        label?: {
            style?: React.CSSProperties;
        };
        container?: {
            style?: React.CSSProperties;
        };
    };
};

type FormState = "processing" | "success" | "error";
interface IProps {
    config: FormBuilderConfig;
    controlProps?: controlProps;
    fileUploaderConfig?: FileUploaderConfig;
    iconType?: string;
    state?: FormState | "";
    resolveUrl?: resolveUrl;
    onSubmit?: (urlEncodedFormValues: string, formValues: any) => Promise<any>;
    postGenAiMessage?: ({ message, profile, }: PostMessageProps) => Promise<PostMessageResponse>;
}
declare const FormBuilder: ({ config, controlProps, fileUploaderConfig, iconType, state, resolveUrl, onSubmit, postGenAiMessage, }: IProps) => react_jsx_runtime.JSX.Element;

export { type IProps as IFormBuilderProps, FormBuilder as default };
